@@ -1312,14 +1312,16 @@ SEXP perform_annotation(SEXP external_descriptor_pointer) {
 	return R_NilValue;
 }
 
-SEXP perform_id_harmonization(SEXP input_file_name, SEXP output_file_name, SEXP map_file_name, SEXP id_column_name, SEXP allele_column_names, SEXP separator, SEXP drop, SEXP gzip) {
+SEXP perform_harmonization(SEXP input_file_name, SEXP output_file_name, SEXP map_file_name, SEXP chr_column_name, SEXP id_column_name, SEXP allele_column_names, SEXP separator, SEXP vcf_alleles, SEXP drop, SEXP gzip) {
 	const char* c_input_file_name = NULL;
 	const char* c_output_file_name = NULL;
 	const char* c_map_file_name = NULL;
+	const char* c_chr_column_name = NULL;
 	const char* c_id_column_name = NULL;
 	const char* c_ref_allele_column_name = NULL;
 	const char* c_nonref_allele_column_name = NULL;
 	const char* c_separator = NULL;
+	int c_vcf_alleles = 0;
 	int c_drop = 0;
 	int c_gzip = 0;
 
@@ -1386,6 +1388,27 @@ SEXP perform_id_harmonization(SEXP input_file_name, SEXP output_file_name, SEXP
 		error("\nThe input file name is blank.");
 	}
 
+	if (chr_column_name == R_NilValue) {
+		error("\nThe chromosome column name is NULL.");
+	}
+
+	if (!isString(chr_column_name)) {
+		error("\nThe chromosome column name is not a string.");
+	}
+
+	if (length(chr_column_name) <= 0) {
+		error("\nThe chromosome column name is empty.");
+	}
+
+	if (length(chr_column_name) > 1) {
+		error("\nThe chromosome column name has multiple values.");
+	}
+
+	c_chr_column_name = CHAR(STRING_ELT(chr_column_name, 0));
+	if ((strlen(c_chr_column_name) <= 0) || (strspn(c_chr_column_name, " \t") == strlen(c_chr_column_name))) {
+		error("\nThe chromosome column name is blank.");
+	}
+
 	if (id_column_name == R_NilValue) {
 		error("\nThe SNP ID column name is NULL.");
 	}
@@ -1468,6 +1491,24 @@ SEXP perform_id_harmonization(SEXP input_file_name, SEXP output_file_name, SEXP
 
 	c_drop = LOGICAL(drop)[0];
 
+	if (vcf_alleles == R_NilValue) {
+		error("\nThe 'vcf_alleles' argument is NULL.");
+	}
+
+	if (!isLogical(vcf_alleles)) {
+		error("\nThe 'vcf_alleles' argument is not logical.");
+	}
+
+	if (length(vcf_alleles) <= 0) {
+		error("\nThe 'vcf_alleles' argument is empty.");
+	}
+
+	if (length(vcf_alleles) > 1) {
+		error("\nThe 'vcf_alleles' argument has multiple values.");
+	}
+
+	c_vcf_alleles = LOGICAL(vcf_alleles)[0];
+
 	if (gzip == R_NilValue) {
 		error("\nThe 'gzip' argument is NULL.");
 	}
@@ -1489,13 +1530,23 @@ SEXP perform_id_harmonization(SEXP input_file_name, SEXP output_file_name, SEXP
 	try {
 		Harmonizer harmonizer;
 
-		harmonizer.open_file(c_input_file_name, c_id_column_name, c_ref_allele_column_name, c_nonref_allele_column_name, c_separator[0u]);
+		harmonizer.open_input_file(c_input_file_name, c_chr_column_name, c_id_column_name, c_ref_allele_column_name, c_nonref_allele_column_name, c_separator[0u]);
+		harmonizer.open_output_file(c_output_file_name, c_gzip);
+		harmonizer.open_log_file(c_output_file_name, c_gzip);
 
 		harmonizer.process_header();
-		harmonizer.index_map(c_map_file_name);
-		harmonizer.harmonize(c_output_file_name, c_drop, c_gzip);
 
-		harmonizer.close_file();
+		harmonizer.index_map(c_map_file_name);
+
+		if (c_vcf_alleles) {
+			harmonizer.harmonize(c_drop);
+		} else {
+			harmonizer.harmonize_no_vcf_allele_check(c_drop);
+		}
+
+		harmonizer.close_input_file();
+		harmonizer.close_output_file();
+		harmonizer.close_log_file();
 	} catch (Exception &e) {
 		error("\n%s", e.what());
 	}
